@@ -1,13 +1,11 @@
 #
-# $Id: Base64.pm,v 2.3 1997/06/27 09:04:40 aas Exp $
+# $Id: Base64.pm,v 2.6 1997/12/02 10:24:26 aas Exp $
 
 package MIME::Base64;
 
 =head1 NAME
 
-encode_base64 - Encode string using base64 encoding
-
-decode_base64 - Decode base64 string
+MIME::Base64 - Encoding and decoding of base64 strings
 
 =head1 SYNOPSIS
 
@@ -44,8 +42,7 @@ broken into lines.
 Decode a base64 string by calling the decode_base64() function.  This
 function takes a single argument which is the string to decode and
 returns the decoded data.  Any character not part of the legal base64
-chars is ignored.  The decode_base64() function might croak if the
-sequence to decode ends prematurely.
+chars is ignored.
 
 =back
 
@@ -56,6 +53,25 @@ call them as:
     $encoded = MIME::Base64::encode($decoded);
     $decoded = MIME::Base64::decode($encoded);
 
+=head1 EXAMPLES
+
+If you want to encode a large file, you should encode it in chunks
+that are a multiple of 57 bytes.  This ensures that the base64 lines
+line up and that you do not end up with padding in the middle. 57
+bytes of data fills one complete base64 line (76 == 57*4/3):
+
+   use MIME::Base64 qw(encode_base64);
+
+   open(FILE, "/var/log/wtmp") or die "$!";
+   while (read(FILE, $buf, 60*57)) {
+       print encode_base64($buf);
+   }
+
+or if you know you have enough memory
+
+   use MIME::Base64 qw(encode_base64);
+   local($/) = undef;  # slurp
+   print encode_base64(<STDIN>);
 
 =head1 COPYRIGHT
 
@@ -82,7 +98,7 @@ require DynaLoader;
 @ISA = qw(Exporter DynaLoader);
 @EXPORT = qw(encode_base64 decode_base64);
 
-$VERSION = '2.02';
+$VERSION = '2.04';
 
 eval { bootstrap MIME::Base64 $VERSION; };
 if ($@) {
@@ -98,7 +114,6 @@ if ($@) {
 # The XS implementation runs about 20 times faster, but the perl
 # code might be more portable, so it is still supported.
 
-use Carp ();
 use integer;
 
 sub old_encode_base64 ($;$)
@@ -131,8 +146,10 @@ sub old_decode_base64 ($)
     my $res = "";
 
     $str =~ tr|A-Za-z0-9+=/||cd;            # remove non-base64 chars
-    Carp::croak("Base64 decoder requires string length to be a multiple of 4")
-      if length($str) % 4;
+    if (length($str) % 4) {
+	require Carp;
+	Carp::croak("Base64 decoder requires string length to be a multiple of 4")
+    }
     $str =~ s/=+$//;                        # remove padding
     $str =~ tr|A-Za-z0-9+/| -_|;            # convert to uuencoded format
     while ($str =~ /(.{1,60})/gs) {
